Building translators community
==============================

Localization guide
------------------

.. versionadded:: 3.9

The :guilabel:`Localization guide` which can be found in the
:guilabel:`Insights` menu of each component can give you guidance to make your
localization process easy for translators.

.. image:: /images/guide.png
